Stan Math Library: stan/math/fwd/scal/fun/log1p_exp.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log1p_exp.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_LOG1P_EXP_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_LOG1P_EXP_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/prim/scal/fun/log1p_exp.hpp>
6
7 namespace stan {
8 namespace math {
9
10 template <typename T>
11 inline
12 fvar<T>
13 log1p_exp(const fvar<T>& x) {
14 using stan::math::log1p_exp;
15 using std::exp;
16 return fvar<T>(log1p_exp(x.val_), x.d_ / (1 + exp(-x.val_)));
17 }
18
19 }
20 }
21 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
log1p_exp.hpp
stan::math::log1p_exp
fvar< T > log1p_exp(const fvar< T > &x)
Definition: log1p_exp.hpp:13
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.